==> net.bluemind.resource.service-4.9.3879.jar: net/bluemind/resource/service/ResourcesServiceFactory.java <==
/* BEGIN LICENSE
 * Copyright © Blue Mind SAS, 2012-2016
 *
 * This file is part of BlueMind. BlueMind is a messaging and collaborative
 * solution.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of either the GNU Affero General Public License as
 * published by the Free Software Foundation (version 3 of the License).
 *
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * See LICENSE.txt
 * END LICENSE
 */
package net.bluemind.resource.service;

import net.bluemind.core.api.fault.ServerFault;
import net.bluemind.core.container.model.Container;
import net.bluemind.core.container.model.ItemValue;
import net.bluemind.core.rest.BmContext;
import net.bluemind.core.rest.ServerSideServiceProvider;
import net.bluemind.directory.service.AbstractDirServiceFactory;
import net.bluemind.domain.api.Domain;
import net.bluemind.resource.api.IResources;
import net.bluemind.resource.service.internal.ResourcesService;

public class ResourcesServiceFactory extends AbstractDirServiceFactory<IResources>
		implements ServerSideServiceProvider.IServerSideServiceFactory<IResources> {

	@Override
	public Class<IResources> factoryClass() {
		return IResources.class;
	}

	@Override
	protected IResources instanceImpl(BmContext context, ItemValue<Domain> domainValue, Container container)
			throws ServerFault {

		return new ResourcesService(context, domainValue, container);

	}
}

==> net.bluemind.resource.service-5.4.2696.jar: net/bluemind/resource/service/ResourcesServiceFactory.java <==
/* BEGIN LICENSE
 * Copyright © Blue Mind SAS, 2012-2016
 *
 * This file is part of BlueMind. BlueMind is a messaging and collaborative
 * solution.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of either the GNU Affero General Public License as
 * published by the Free Software Foundation (version 3 of the License).
 *
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * See LICENSE.txt
 * END LICENSE
 */
package net.bluemind.resource.service;

import net.bluemind.core.api.fault.ServerFault;
import net.bluemind.core.container.model.BaseContainerDescriptor;
import net.bluemind.core.container.model.Container;
import net.bluemind.core.container.model.ItemValue;
import net.bluemind.core.container.service.internal.ItemValueAuditLogService;
import net.bluemind.core.rest.BmContext;
import net.bluemind.core.rest.ServerSideServiceProvider;
import net.bluemind.directory.service.AbstractDirServiceFactory;
import net.bluemind.directory.service.DirEntryAndValue;
import net.bluemind.domain.api.Domain;
import net.bluemind.resource.api.IResources;
import net.bluemind.resource.api.ResourceDescriptor;
import net.bluemind.resource.service.internal.AuditLogDirEntryResourceMapper;
import net.bluemind.resource.service.internal.ResourcesService;

public class ResourcesServiceFactory extends AbstractDirServiceFactory<IResources>
		implements ServerSideServiceProvider.IServerSideServiceFactory<IResources> {

	@Override
	public Class<IResources> factoryClass() {
		return IResources.class;
	}

	@Override
	protected IResources instanceImpl(BmContext context, ItemValue<Domain> domainValue, Container container)
			throws ServerFault {

		BaseContainerDescriptor descriptor = BaseContainerDescriptor.create(container.uid, container.name,
				container.owner, container.type, container.domainUid, container.defaultContainer);
		descriptor.internalId = container.id;
		AuditLogDirEntryResourceMapper mapper = new AuditLogDirEntryResourceMapper();
		ItemValueAuditLogService<DirEntryAndValue<ResourceDescriptor>> logService = new ItemValueAuditLogService<>(
				context, descriptor, mapper);
		return new ResourcesService(context, domainValue, container, logService);

	}
}
